// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

package com.network_type;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;

/**
 * The handler receives {@link MethodCall}s from the UIThread, gets the related information from
 * a @{@link ConnectivityType}, and then send the result back to the UIThread through the {@link
 * MethodChannel.Result}.
 */
class ConnectivityMethodHandler implements MethodChannel.MethodCallHandler {

  private ConnectivityType connectivityType;

  /**
   * Construct the ConnectivityMethodHandler with a {@code connectivityType}. The {@code
   * connectivityType} must not be null.
   */
  ConnectivityMethodHandler(ConnectivityType connectivityType) {
    assert (connectivityType != null);
    this.connectivityType = connectivityType;
  }

  @Override
  public void onMethodCall(MethodCall call, MethodChannel.Result result) {
    switch (call.method) {
      case "check":
        result.success(connectivityType.getNetworkType());
        break;
      case "wifiName":
        result.success(connectivityType.getWifiName());
        break;
      case "wifiBSSID":
        result.success(connectivityType.getWifiBSSID());
        break;
      case "wifiIPAddress":
        result.success(connectivityType.getWifiIPAddress());
        break;
      case "getPlatformVersion":
        result.success("Android " + android.os.Build.VERSION.RELEASE);
        break;
      case "networkType":
        result.success(connectivityType.getNetworkSubtype());
        break;
      default:
        result.notImplemented();
        break;
    }
  }
}
